pub struct ValidationError {
pub path: FieldPath,
pub code: String,
pub message: String,
pub params: BTreeMap<String, ErrorParam>,
}Expand description
A single validation error with path, code, and message.
Example
use skp_validator_core::{ValidationError, FieldPath};
let error = ValidationError::new("email", "email.invalid", "Must be a valid email address")
.with_param("value", "invalid-email");Fields
path: FieldPathPath to the field that failed validation
code: StringError code for programmatic handling (e.g., “email.invalid”, “length.min”)
message: StringHuman-readable error message
params: BTreeMap<String, ErrorParam>Additional parameters for error formatting and i18n
Implementations
Sourceimpl ValidationError
impl ValidationError
Sourcepub fn new(
field: impl Into<String>,
code: impl Into<String>,
message: impl Into<String>,
) -> ValidationError
pub fn new( field: impl Into<String>, code: impl Into<String>, message: impl Into<String>, ) -> ValidationError
Create a new validation error.
Arguments
field- The field name (will be converted to a FieldPath)code- Error code for programmatic handlingmessage- Human-readable message
Sourcepub fn with_path(
path: FieldPath,
code: impl Into<String>,
message: impl Into<String>,
) -> ValidationError
pub fn with_path( path: FieldPath, code: impl Into<String>, message: impl Into<String>, ) -> ValidationError
Create a new validation error with a full path.
Sourcepub fn root(
code: impl Into<String>,
message: impl Into<String>,
) -> ValidationError
pub fn root( code: impl Into<String>, message: impl Into<String>, ) -> ValidationError
Create a root-level error (empty path).
Sourcepub fn with_param(
self,
key: impl Into<String>,
value: impl Into<ErrorParam>,
) -> ValidationError
pub fn with_param( self, key: impl Into<String>, value: impl Into<ErrorParam>, ) -> ValidationError
Add a parameter to this error.
Sourcepub fn field_name(&self) -> Option<&str>
pub fn field_name(&self) -> Option<&str>
Get the field name (last segment of path)